class ocpattrauth::params {

  case $::operatingsystem {
    RedHat,CentOS,Scientific: {
      case $::operatingsystemmajrelease {
        6: {
          $tomcat = "tomcat6"
          $mysqlpkg = "mysql-server"
        }
        default: {
          $tomcat = "tomcat"
          $mysqlpkg = "mariadb-server"
        }
      }
      $default_truststore = "/etc/pki/ca-trust/extracted/java/cacerts"
      $default_catalina_home = "/usr/share/${tomcat}"
    }
    Ubuntu: {
      $tomcat = "tomcat8"
      $mysqlpkg = "mariadb-server"
      $default_truststore = "/etc/ssl/certs/java/cacerts"
      $default_catalina_home = "/var/lib/${tomcat}"
    }
  }
  
  $db_defaults = {
    "c3p0.min_size"                 => "5",
    "c3p0.max_size"                 => "20",
    "c3p0.timeout"                  => "60",
    "c3p0.max_statements"           => "50",
    "c3p0.idle_test_period"         => "3000",
    "c3p0.testConnectionOnCheckout" => "true"
  }

  $aa_host                   = hiera("ocp::aa::host", "${::fqdn}")
  $aa_port                   = hiera("ocp::aa::port", "443")
  
  $aa_entity_id              = hiera("ocp::aa::entityid", "${aa_host}:${aa_port}:it.infn.security.saml")
  $aa_metadata_exp           = hiera("ocp::aa::metadata_expiration", "432000")
  
  $max_connections           = hiera("ocp::aa::db::max_conn", "500")
  $db_bind_address           = hiera("ocp::aa::db::bind_address", "127.0.0.1")
  $mysql_password            = hiera("ocp::aa::db::root_password")
  $aa_db_name                = hiera("ocp::aa::db::name", "saml2aadb")
  $aa_db_user                = hiera("ocp::aa::db::user", "srvuser")
  $aa_db_password            = hiera("ocp::aa::db::password")
  $aa_db_host                = hiera("ocp::aa::db::host", "localhost")
  $aa_db_port                = hiera("ocp::aa::db::port", "3306")
  $db_parameters             = hiera("ocp::aa::db::poolparams", $db_defaults)

  $war_file_url              = hiera("ocp::aa::war_file::url", "http://igi-01.pd.infn.it/mrepo/OCP/AttributeAuthority/saml2-attribute-authority.war")
  
  $contacts                  = hiera("ocp::aa::contacts", [])
  $organization              = hiera("ocp::aa::organization", {})
  $admins                    = hiera("ocp::aa::administrators", [])
  $banned                    = hiera("ocp::aa::banned_users", [])
  
  $catalina_home             = hiera("ocp::tomcat::catalina_home", "${default_catalina_home}")
  $keystore_file             = hiera("ocp::tomcat::keystore::file")
  $keystore_type             = hiera("ocp::tomcat::keystore::type", "JKS")
  $keystore_pwd              = hiera("ocp::tomcat::keystore::password")
  $keystore_alias            = hiera("ocp::tomcat::keystore::alias")
  $truststore_file           = hiera("ocp::tomcat::truststore::file", "${default_truststore}")
  $truststore_type           = hiera("ocp::tomcat::truststore::type", "JKS")
  $truststore_pwd            = hiera("ocp::tomcat::truststore::password", "changeit")

}
